AxisBoundedSelection class abstract

Describes a SelectionWithEdges in which is completely bounded in one Axis and partially or no bounded in the other axis (called here cross-axis).

Since it subclasses an one dimensional Range, start and end act as the edges (RangeEdge) in the main axis

Implemented types
Implementers
Available extensions

Constructors

AxisBoundedSelection.crossAxisPartiallyBounded({required Axis axis, required RangeEdge anchorEdge, required int start, required int end, required RangeEdge crossAxisBoundedEdge, required int crossAxisBound})
Creates a AxisBoundedSelection in which the opposite axis to axis is partially bounded, this means that at least the and or start edges of that axis should be provided.
const
AxisBoundedSelection.crossAxisUnbounded({required Axis axis, required RangeEdge anchorEdge, required int start, required int end})
Creates a AxisBoundedSelection in which the opposite axis to axis is unbounded in both edges.
const

Properties

anchor → int
The edge that should include anchorCoordinate. anchor is the origin of a selection, it is the edge that should remain unchanged in an expansion operation.
no setteroverride
anchorCoordinate → IntVector2
The anchorCoordinate is the first coordinate of the given anchor column/row.
no setteroverride
anchorEdge → RangeEdge
Defines with RangeEdge of the bounded axis represents the anchor.
final
axis → Axis
The axis completely bounded by start ad end.
final
bottom → int?
no setteroverride
crossAxisBound → int?
A dimensional index in the cross axis that defines one of its edges (as on crossAxisBoundedEdge.
final
crossAxisBoundedEdge → RangeEdge?
Specified by AxisBoundedSelection.crossAxisPartiallyBounded defines which edge of the crossAxis crossAxisBound represents.
final
end → int
finalinherited
focus → int
The edge that should include focusCoordinate. Focus should correspond the edge that should be changed in a expansion operation.
no setteroverride
focusCoordinate → IntVector2
The focusCoordinate is the first coordinate of the given focus column/row.
no setteroverride
hashCode → int
The hash code for this object.
no setter
isNil → bool
If this is a range with no elements
no setterinherited
isNotNil → bool
If this is a range with any element
no setterinherited
iterable → Iterable<int>
no setterinherited
left → int?
no setteroverride
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int
finalinherited
style → SelectionStyle?
no setterinherited
top → int?
no setteroverride

Methods

bound({required Range2D to}) → Range2D

Available on Selection, provided by the SelectionMethods extension

Bound a Selection to a Range2D.
clone() → Range
Create a identical range
inherited
contains(Object? position) → bool
Verifies if a given position is contained within the range
inherited
containsRange(Range otherRange) → bool
Defines if this range contains otherRange entirely
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
overlaps(Range otherRange) → bool
Defines if this range overlaps otherRange
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator &(Range otherRange) → Range
Gets the intersection between two ranges, range nil if they don't intersect
inherited
operator +(Range otherRange) → RangeCompactList
Performs a union with another range merge if overlaps
inherited
operator -(Range otherRange) → RangeCompactList
Return all the elements on the this range that is not present on the otherRange.
inherited
operator ==(Object other) → bool
The equality operator.
operator |(Range otherRange) → Range
Stretches and merges two ranges including all possible non covered spaces between them
inherited