Selection class abstract

The most simple description of a portion of the grid that is supposed to be selected or to receive a special decoration (defined by style).

Bottom and right values are non-inclusive, this means that a selection with a bottom value of 14 includes up to the row with index 13.

Each side of the regularly rectangle-shaped region can receive a null value, This mens that the selection ahs no clear bound (unbounded) for that size, deferring the boundaries to the size of the table.

For example, a selection with the following side values:

  • left: 4
  • top: 2
  • right: null
  • bottom 4

That selection will include all cells in the rows 2 and 3 and in the columns starting from 4 until the end of the table to the right.

A table with both top and bottom values set to null will include entire columns. The same applies to left and right selecting entire rows.

A table with all side values set to null will include all cells of a table.

Side values are assumed to be normalized, then subclasses should make sure that these conditions are always true:

  • top <= bottom
  • left <= right
Implementers
Available extensions
Annotations

Constructors

Selection()

Properties

anchorCoordinate → IntVector2
The coordinate within the selection that describes its 'origin', usually diametrically opposed to focusCoordinate.
no setter
bottom → int?
no setter
focusCoordinate → IntVector2
The coordinate within the selection that describes the location where further directional changes should be based on.
no setter
hashCode → int
The hash code for this object.
no setterinherited
left → int?
no setter
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → SelectionStyle?
no setter
top → int?
no setter

Methods

bound({required Range2D to}) → Range2D

Available on Selection, provided by the SelectionMethods extension

Bound a Selection to a Range2D.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited