SwayzeController class abstract

The main controller on swayze.

A controller is way of widgets providing an API for having parts of its state to be controlled externally.

SwayzeController allows changes to be made to a table during its lifetime from inside an outside the SliverSwayzeTable widget.

Each controller instance should be passed to a single SliverSwayzeTable and disposed when the table is supposed to leave the widget tree.

See also:

Inheritance

Constructors

SwayzeController()

Properties

cellsController → SwayzeCellsController<SwayzeCellData>
no setter
hashCode → int
The hash code for this object.
no setterinherited
inlineEditor → SwayzeInlineEditorController
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scroll → SwayzeScrollController<SwayzeController>
latefinal
selection → SwayzeSelectionController
The controller that contains the state related to selections on the table.
latefinal
tableDataController → SwayzeTableDataController<SwayzeController>
The controller that contains the state related to columns/rows and the table's meta information.
no setter

Methods

dispose() → void
When set to be removed, controllers may have listeners and other references that may create memory dead dependency. dispose should drop such references.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited