SwayzeHeaderData class

Annotations

Constructors

SwayzeHeaderData({required int index, required double? extent, required bool hidden})
const

Properties

effectiveExtent → double
no setter
extent → double?
final
hashCode → int
The hash code for this object.
no setteroverride
hidden → bool
final
index → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? extent, bool? hidden}) → SwayzeHeaderData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override