TableUserSelectionModel class

A completely unbounded UserSelectionModel. It selects the entire table.

Implemented types
Available extensions

Properties

anchorCoordinate ↔ IntVector2
The coordinate within the selection that describes its 'origin', usually diametrically opposed to focusCoordinate.
latefinaloverride-getter
bottom → int?
no setteroverride
focusCoordinate → IntVector2
The coordinate within the selection that describes the location where further directional changes should be based on.
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
id → String
Unique identifier of a selection in a UserSelectionState
final
left → int?
no setteroverride
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → SelectionStyle?
final
top → int?
no setteroverride

Methods

bound({required Range2D to}) → Range2D

Available on Selection, provided by the SelectionMethods extension

Bound a Selection to a Range2D.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override