UserSelectionModel class abstract

Defines a Selection that is controllable by a UserSelectionState.

Inheritance
Implementers
Available extensions

Constructors

UserSelectionModel()

Properties

anchorCoordinate → IntVector2
The coordinate within the selection that describes its 'origin', usually diametrically opposed to focusCoordinate.
no setterinherited
bottom → int?
no setterinherited
focusCoordinate → IntVector2
The coordinate within the selection that describes the location where further directional changes should be based on.
no setterinherited
hashCode → int
The hash code for this object.
no setteroverride
id → String
Unique identifier of a selection in a UserSelectionState
no setter
left → int?
no setterinherited
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → SelectionStyle?
no setterinherited
top → int?
no setterinherited

Methods

bound({required Range2D to}) → Range2D

Available on Selection, provided by the SelectionMethods extension

Bound a Selection to a Range2D.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override