CellPositionResult class

A result of a conversion of a cell's coordinates into it's offset and size

See also:

Annotations

Constructors

CellPositionResult({bool isOffscreenY = false, bool isOffscreenX = false, required Offset leftTop, required Size cellSize})
const
CellPositionResult.offscreen({required bool isOffscreenY, required bool isOffscreenX})
factory

Properties

cellSize → Size
final
hashCode → int
The hash code for this object.
no setteroverride
isOffscreen → bool
no setter
isOffscreenX → bool
final
isOffscreenY → bool
final
leftTop → Offset
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override