OffscreenDetails enum

Used by PixelResult and PositionResult to describe if the result is off the viewport.

Inheritance
Available extensions

Values

noOverflow → const OffscreenDetails
leading → const OffscreenDetails
trailing → const OffscreenDetails

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
isOffscreen → bool

Available on OffscreenDetails, provided by the OverflowViewportMethods extension

Defines if a OffscreenDetails describes a overflow situation.
no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<OffscreenDetails>
A constant List of the values in this enum, in order of their declaration.