PixelResult class

A result of a conversion of a column/row index into a pixel offset.

See also:

Annotations

Constructors

PixelResult({required Axis axis, required OffscreenDetails offscreenDetails, required double pixel})
const

Properties

axis → Axis
Defines if the original index is either of a column or of a row.
final
hashCode → int
The hash code for this object.
no setteroverride
offscreenDetails → OffscreenDetails
Defines if this column/row is outside the viewport.
final
pixel → double
Is the pixel offset of the leading edge of the column/row bound to the viewport dimensions.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override