SliverSwayzeTable<CellDataType extends SwayzeCellData> class

A sliver StatefulWidget that represents one single table on a scroll view.

See also:

  • SliverTwoAxisScroll the sliver that adds horizontal scroll in addition to the vertical scroll given by SwayzeEditorMain
Inheritance

Constructors

SliverSwayzeTable({Key? key, required SwayzeController controller, required FocusNode focusNode, required ScrollController verticalScrollController, bool? autofocus, Widget? stickyHeader, double? stickyHeaderSize, SwayzeStyle? style, required InlineEditorBuilder inlineEditorBuilder, required CellDelegate<CellDataType> cellDelegate, WrapBoxBuilder? wrapBox, WrapTableBodyBuilder? wrapTableBody, WrapHeaderBuilder? wrapHeader})

Properties

autofocus → bool
Defines if the widget should autofocus on build
final
cellDelegate → CellDelegate<CellDataType>
final
controller → SwayzeController
Defines the controller for the internal state of this table.
final
focusNode → FocusNode
Controls focus of this table.
final
hashCode → int
The hash code for this object.
no setterinherited
inlineEditorBuilder → InlineEditorBuilder
The Builder that generates the widget that will be rendered when the user will edit a particular cell inline, that is, in the same physical spot occupied by the cell in the screen.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
A widget to be rendered on the before the table in the scroll view. Its height is defined by SwayzeStyle.stickyHeaderSize.
final
stickyHeaderSize → double?
The height of the stickyHeaderSize. Cannot be null if stickyHeader is defined.
final
style → SwayzeStyle
The style of the table, defaults to SwayzeStyle.defaultSwayzeStyle.
final
verticalScrollController → ScrollController
The ScrollController that manages the external vertical scroll view.
final
wrapBox → WrapBoxBuilder?
Builder to wrap the box part of the table with box widgets that cannot wrap SliverSwayzeTable directly because it is a sliver, like a FocusTrapArea for example.
final
wrapHeader → WrapHeaderBuilder?
Builder to wrap the headers of the table.
final
wrapTableBody → WrapTableBodyBuilder?
Builder to wrap the table body of the table.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → SliverSwayzeTableState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited